@@ -112,7 +112,7 @@ from pyglet.gl import (
     GL_TEXTURE_MAG_FILTER, GL_TEXTURE_MIN_FILTER, GL_TRIANGLES, GL_UNPACK_ALIGNMENT, GL_UNPACK_ROW_LENGTH,
     GL_UNPACK_SKIP_PIXELS, GL_UNPACK_SKIP_ROWS, GL_UNSIGNED_BYTE, GL_VIEWPORT, GLint, GLubyte, GLuint, glActiveTexture,
     glBindFramebuffer, glBindImageTexture, glBindTexture, glBindVertexArray, glCheckFramebufferStatus,
-    glCompressedTexImage2D, glCompressedTexSubImage2D, glCompressedTexSubImage3D, glCopyTexSubImage2D,
+    glCompressedTexImage2D, glCompressedTexSubImage2D, glCompressedTexSubImage3D, glCopyTexSubImage2D, glCopyTexImage2D,
     glDeleteFramebuffers, glDeleteTextures, glDeleteVertexArrays, glDrawElements, glFlush, glFramebufferTexture2D,
     glGenFramebuffers, glGenTextures, glGenVertexArrays, glGenerateMipmap, glGetFramebufferAttachmentParameteriv,
     glGetIntegerv, glGetTexImage, glPixelStorei, glReadBuffer, glReadPixels, glTexImage2D, glTexImage3D,
@@ -556,7 +556,7 @@ class ImageData(AbstractImage):
         Note:
              Conversion to another format is done on the CPU, and can be
              somewhat costly for larger images. Consider performing conversion
-             at load time for framerate sensitive applictions.
+             at load time for framerate sensitive applications.
         """
         fmt = fmt or self._desired_format
         pitch = pitch or self._current_pitch
@@ -647,7 +647,7 @@ class ImageData(AbstractImage):
 
     def get_texture(self, rectangle: bool = False) -> Texture:
         if not self._current_texture:
-            self._current_texture = self.create_texture(Texture, rectangle)
+            self._current_texture = self.create_texture(Texture)
         return self._current_texture
 
     def get_mipmapped_texture(self) -> Texture:
@@ -1167,10 +1167,13 @@ class Texture(AbstractImage):
     default will be used. 
     """
 
-    def __init__(self, width: int, height: int, target: int, tex_id: int) -> None:
+    def __init__(self, width: int, height: int, target: int, tex_id: int,
+                 min_filter: int | None = None, mag_filter: int | None = None) -> None:
         super().__init__(width, height)
         self.target = target
         self.id = tex_id
+        self.min_filter = min_filter or self.default_min_filter
+        self.mag_filter = mag_filter or self.default_mag_filter
         self._context = pyglet.gl.current_context
 
     def delete(self) -> None:
@@ -1198,7 +1201,7 @@ class Texture(AbstractImage):
                            layer: int = 0, access: int = GL_READ_WRITE, fmt: int = GL_RGBA32F):
         """Bind as an ImageTexture for use with a :py:class:`~pyglet.shader.ComputeShaderProgram`.
 
-        .. note:: OpenGL 4.3, or 4.2 with the GL_ARB_compute_shader extention is required.
+        .. note:: OpenGL 4.3, or 4.2 with the GL_ARB_compute_shader extension is required.
         """
         glBindImageTexture(unit, self.id, level, layered, layer, access, fmt)
 
@@ -1208,7 +1211,7 @@ class Texture(AbstractImage):
                fmt: int = GL_RGBA, blank_data: bool = True) -> Texture:
         """Create a Texture
 
-        Create a Texture with the specified dimentions, target and format.
+        Create a Texture with the specified dimensions, target and format.
         On return, the texture will be bound.
 
         Args:
@@ -1253,12 +1256,7 @@ class Texture(AbstractImage):
                          blank)
             glFlush()
 
-        texture = cls(width, height, target, tex_id.value)
-        texture.min_filter = min_filter
-        texture.mag_filter = mag_filter
-        texture.tex_coords = cls.tex_coords
-
-        return texture
+        return cls(width, height, target, tex_id.value, min_filter, mag_filter)
 
     def get_image_data(self, z: int = 0) -> ImageData:
         """Get the image data of this texture.
@@ -2123,7 +2121,7 @@ class BufferImage(AbstractImage):
         region.owner = self
         return region
 
-    def get_texture(self, rectangle: bool = False) -> Texture:
+    def get_texture(self) -> Texture:
         raise NotImplementedError(f"Not implemented for {self}")
 
     def get_mipmapped_texture(self) -> Texture:
@@ -2148,7 +2146,7 @@ class ColorBufferImage(BufferImage):
     gl_format = GL_RGBA
     format = 'RGBA'
 
-    def get_texture(self, rectangle=False):
+    def get_texture(self):
         texture = Texture.create(self.width, self.height, GL_TEXTURE_2D, GL_RGBA, blank_data=False)
         self.blit_to_texture(texture.target, texture.level, self.anchor_x, self.anchor_y, 0)
         return texture
@@ -2165,9 +2163,9 @@ class DepthBufferImage(BufferImage):
     gl_format = GL_DEPTH_COMPONENT
     format = 'R'
 
-    def get_texture(self, rectangle=False):
+    def get_texture(self):
         image_data = self.get_image_data()
-        return image_data.get_texture(rectangle)
+        return image_data.get_texture()
 
     def blit_to_texture(self, target: int, level: int, x: int, y: int, z: int, internalformat: int = None):
         # TODO: use glCopyTexImage2D if `internalformat` is specified.
